@@ -11,6 +11,7 @@
 #include "tsk/tsk_tools_i.h"
 #include "tsk/auto/tsk_case_db.h"
 #include "tsk/hashdb/tsk_hash_info.h"
+#include "tsk/auto/tsk_is_image_supported.h"
 #include "jni.h"
 #include "dataModel_SleuthkitJNI.h"
 #include <locale.h>
@@ -919,17 +920,39 @@ JNIEXPORT jobject JNICALL Java_org_sleuthkit_datamodel_SleuthkitJNI_hashDbLookup
 }
 
 /*
- * Create an add-image process that can later be run with specific inputs
- * @return the pointer to the process or NULL on error
- * @param env pointer to java environment this was called from
- * @partam caseHandle pointer to case to add image to
- * @param timezone timezone for the image
- * @param addUnallocSpace whether to create virtual files for the unallocated space in the disk image
- * @param noFatFsOrphans whether to skip processing orphans on FAT filesystems
+ * Initialize a process for adding an image to a case database.
+ *
+ * @param env Pointer to java environment.
+ * @param obj Pointer the Java class object.
+ * @partam caseHandle Pointer to a TskCaseDb object.
+ * @param timeZone The time zone for the image.
+ * @param addUnallocSpace Pass true to create virtual files for unallocated space. Ignored if addFileSystems is false.
+ * @param skipFatFsOrphans Pass true to skip processing of orphan files for FAT file systems. Ignored if addFileSystems is false.
+ *
+ * @return A pointer to the process (TskAutoDb object) or NULL on error.
  */
 JNIEXPORT jlong JNICALL
     Java_org_sleuthkit_datamodel_SleuthkitJNI_initAddImgNat(JNIEnv * env,
-    jclass obj, jlong caseHandle, jstring timezone, jboolean addUnallocSpace, jboolean noFatFsOrphans) {
+    jclass obj, jlong caseHandle, jstring timeZone, jboolean addUnallocSpace, jboolean skipFatFsOrphans) {
+    return Java_org_sleuthkit_datamodel_SleuthkitJNI_initializeAddImgNat(env, obj, caseHandle, timeZone, true, addUnallocSpace, skipFatFsOrphans);
+}
+
+/*
+ * Initialize a process for adding an image to a case database.
+ *
+ * @param env Pointer to java environment.
+ * @param obj Pointer the Java class object.
+ * @partam caseHandle Pointer to a TskCaseDb object.
+ * @param timeZone The time zone for the image.
+ * @param addFileSystems Pass true to attempt to add file systems within the image to the case database.
+ * @param addUnallocSpace Pass true to create virtual files for unallocated space. Ignored if addFileSystems is false.
+ * @param skipFatFsOrphans Pass true to skip processing of orphan files for FAT file systems. Ignored if addFileSystems is false.
+ *
+ * @return A pointer to the process (TskAutoDb object) or NULL on error.
+ */
+JNIEXPORT jlong JNICALL
+    Java_org_sleuthkit_datamodel_SleuthkitJNI_initializeAddImgNat(JNIEnv * env, jclass obj, 
+    jlong caseHandle, jstring timeZone, jboolean addFileSystems, jboolean addUnallocSpace, jboolean skipFatFsOrphans) {
     jboolean isCopy;
 
     TskCaseDb *tskCase = castCaseDb(env, caseHandle);
@@ -938,11 +961,11 @@ JNIEXPORT jlong JNICALL
         return 0;
     }
 
-    if (env->GetStringUTFLength(timezone) > 0) {
-        const char *tzstr = env->GetStringUTFChars(timezone, &isCopy);
+    if (env->GetStringUTFLength(timeZone) > 0) {
+        const char *tzstr = env->GetStringUTFChars(timeZone, &isCopy);
 
         if (strlen(tzstr) > 64) {
-            env->ReleaseStringUTFChars(timezone, tzstr);
+            env->ReleaseStringUTFChars(timeZone, tzstr);
             stringstream ss;
             ss << "Timezone is too long";
             setThrowTskCoreError(env, ss.str().c_str());
@@ -951,7 +974,7 @@ JNIEXPORT jlong JNICALL
 
         char envstr[70];
         snprintf(envstr, 70, "TZ=%s", tzstr);
-        env->ReleaseStringUTFChars(timezone, tzstr);
+        env->ReleaseStringUTFChars(timeZone, tzstr);
 
         if (0 != putenv(envstr)) {
             stringstream ss;
@@ -972,13 +995,19 @@ JNIEXPORT jlong JNICALL
     }
 
     // set the options flags
-    if (addUnallocSpace) {
-        tskAuto->setAddUnallocSpace(true, 500*1024*1024);
-    }
-    else {
+    tskAuto->setAddFileSystems(addFileSystems?true:false);
+    if (addFileSystems) {
+        if (addUnallocSpace) {
+            tskAuto->setAddUnallocSpace(true, 500*1024*1024);
+        }
+        else {
+            tskAuto->setAddUnallocSpace(false);
+        }
+        tskAuto->setNoFatFsOrphans(skipFatFsOrphans?true:false);
+    } else {
         tskAuto->setAddUnallocSpace(false);
+        tskAuto->setNoFatFsOrphans(true);
     }
-    tskAuto->setNoFatFsOrphans(noFatFsOrphans?true:false);
 
     // we don't use the block map and it slows it down
     tskAuto->createBlockMap(false);
@@ -989,7 +1018,6 @@ JNIEXPORT jlong JNICALL
     return (jlong) tskAuto;
 }
 
-
 /*
  * Add an image to a database using a pre-created process, which can be cancelled.
  * MUST call commitAddImg or revertAddImg afterwards once runAddImg returns.  If there is an 
@@ -1644,6 +1672,14 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readFsNat(JNIEnv * env,
 }
 
 
+/**
+ * Flag used by readFileNat to specify if the offset is relative to the start of the file
+ * or the start of the slack space 
+ */
+typedef enum {
+	TSK_FS_FILE_READ_OFFSET_TYPE_START_OF_FILE = 0x00,
+	TSK_FS_FILE_READ_OFFSET_TYPE_START_OF_SLACK = 0x01,
+} TSK_FS_FILE_READ_OFFSET_TYPE_ENUM;
 
 /*
  * Read bytes from the given file
@@ -1657,7 +1693,7 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readFsNat(JNIEnv * env,
  */
 JNIEXPORT jint JNICALL
 Java_org_sleuthkit_datamodel_SleuthkitJNI_readFileNat(JNIEnv * env,
-    jclass obj, jlong a_file_handle, jbyteArray jbuf, jlong offset, jlong len)
+    jclass obj, jlong a_file_handle, jbyteArray jbuf, jlong offset, jint offset_type, jlong len)
 {
 	//use fixed size stack-allocated buffer if possible
     char fixed_buf [FIXED_BUF_SIZE];
@@ -1684,9 +1720,16 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readFileNat(JNIEnv * env,
 
     TSK_FS_ATTR * tsk_fs_attr = file_handle->fs_attr;
 
+    TSK_FS_FILE_READ_FLAG_ENUM readFlag = TSK_FS_FILE_READ_FLAG_NONE;
+    TSK_OFF_T readOffset = (TSK_OFF_T) offset;
+    if(offset_type == TSK_FS_FILE_READ_OFFSET_TYPE_START_OF_SLACK){
+        readFlag = TSK_FS_FILE_READ_FLAG_SLACK;
+        readOffset += tsk_fs_attr->size;
+    }
+
     //read attribute
-    ssize_t bytesread = tsk_fs_attr_read(tsk_fs_attr,  (TSK_OFF_T) offset, buf, (size_t) len,
-        TSK_FS_FILE_READ_FLAG_NONE);
+    ssize_t bytesread = tsk_fs_attr_read(tsk_fs_attr,  readOffset, buf, (size_t) len,
+        readFlag);
     if (bytesread == -1) {
         if (dynBuf) {
             free(buf);
@@ -1978,3 +2021,43 @@ JNIEXPORT jlong JNICALL Java_org_sleuthkit_datamodel_SleuthkitJNI_findDeviceSize
 
       return devSize;
 }
+
+/*
+ * Test whether an image is supported
+ * @param env pointer to java environment this was called from
+ * @param obj the java object this was called from
+ * @param imagePathJ the image path
+ * @return true if the image can be processed, false otherwise
+ */
+JNIEXPORT jboolean JNICALL Java_org_sleuthkit_datamodel_SleuthkitJNI_isImageSupportedNat
+  (JNIEnv * env, jclass obj, jstring imagePathJ) {
+      
+    TskIsImageSupported tskIsImage;
+    TSK_TCHAR imagePathT[1024];
+    toTCHAR(env, imagePathT, 1024, imagePathJ);
+
+    // It seems like passing &imagePathT should work instead of making this new array,
+    // but it generated an EXCEPTION_ACCESS_VIOLATION during testing.
+    TSK_TCHAR ** imagePaths = (TSK_TCHAR**)tsk_malloc((1) * sizeof(TSK_TCHAR*));
+    bool result;
+    imagePaths[0] = imagePathT;
+    if (tskIsImage.openImage(1, imagePaths, TSK_IMG_TYPE_DETECT, 0)) {
+        result = false;
+    } else {
+        if (tskIsImage.findFilesInImg()) {
+            result = false;
+        } else {
+            if (tskIsImage.isImageSupported()) {
+                result = true;
+            }
+            else {
+                result = false;
+            }   
+        }
+    }
+
+    // Cleanup
+    free(imagePaths);
+
+    return (jboolean) result;
+}
